@@ -1,68 +1,119 @@
 #number of deaths between age x and x+t
-dxt<-function(object, x, t, decrement) {
-	#checks
-	out<-numeric(1)
-	if (!(class(object) %in% c("lifetable","actuarialtable","mdt"))) stop("Error! Only lifetable, actuarialtable or mdt classes are accepted")
-	if(missing(x)) stop("Error! Missing x")
-	if(missing(t)) t=1
-	omega=getOmega(object) #prima object+1
-	if(class(object)=="mdt") { #call specific function for MDT class
-		if(!missing(decrement)) out<-.dxt.mdt(object=object, x=x, time = t, decrement=decrement) else out<-.dxt.mdt(object=object, x=x, time = t)
-	} else {
-#		if(missing(x)) stop("Error! Missing x")
-#		if(missing(t)) t=1
-#		omega=getOmega(object) #prima object+1
-		#check if fractional
-		if ((t%%1)==0) {
-		lx=object@lx[which(object@x==x)]
-		if((x+t)>omega) out=lx else #before >=
-			out=lx-object@lx[which(object@x==t+x)]
-		} else {
-			fracPart<-(t%%1)
-			intPart<-t-fracPart
-			out<-dxt(object=object, x=x, t=intPart)+fracPart*dxt(object=object, x=x+intPart, t=1)
-		}
-	}
-	return(out)
+dxt <- function(object, x, t, decrement) {
+  #checks
+  out <- numeric(1)
+  if (!(class(object) %in% c("lifetable","actuarialtable","mdt")))
+    stop("Error! Only lifetable, actuarialtable or mdt classes are accepted")
+  if (missing(x))
+    stop("Error! Missing x")
+  if (missing(t))
+    t = 1
+  omega = getOmega(object) #prima object+1
+  if (class(object) == "mdt") {
+    #call specific function for MDT class
+    if (!missing(decrement))
+      out <-
+        .dxt.mdt(
+          object = object, x = x, time = t, decrement = decrement
+        )
+    else
+      out <- .dxt.mdt(object = object, x = x, time = t)
+  } else {
+    #		if(missing(x)) stop("Error! Missing x")
+    #		if(missing(t)) t=1
+    #		omega=getOmega(object) #prima object+1
+    #check if fractional
+    if ((t %% 1) == 0) {
+      lx = object@lx[which(object@x == x)]
+      if ((x + t) > omega)
+        out = lx
+      else
+        #before >=
+        out = lx - object@lx[which(object@x == t + x)]
+    } else {
+      fracPart <- (t %% 1)
+      intPart <- t - fracPart
+      out <-
+        dxt(object = object, x = x, t = intPart) + fracPart * dxt(object = object, x =
+                                                                    x + intPart, t = 1)
+    }
+  }
+  return(out)
 }
 
 #survival probability between age x and x+t
-pxt<-function(object, x, t, fractional="linear", decrement)
+pxt <- function(object, x, t, fractional = "linear", decrement)
 {
-	out<-NULL
-	#checks
-	if (!(class(object) %in% c("lifetable","actuarialtable","mdt"))) stop("Error! Only lifetable, actuarialtable or mdt classes are accepted")
-	if (class(object)=="mdt") { #specific function for multiple decrements
-		out<-ifelse(missing(decrement),1-.qxt.mdt(object=object,x=x,t=t),1-.qxt.mdt(object=object,x=x,t=t,decrement=decrement))
-		return(out)
-	}
-	if(missing(x)) stop("Missing x")
-	if(any(x<0,t<0)) stop("Check x or t domain")
-	if(missing(t)) t=1 #default 1
-	omega=getOmega(object)
-	#if the starting age is fractional apply probability laws
-	if((x-floor(x))>0) {
-		integerAge=floor(x)
-		excess=x-floor(x)
-		out=pxt(object=object, x=integerAge, t=excess+t, decrement=decrement)/pxt(object=object, x=integerAge,t=excess, decrement=decrement)
-		return(out)
-	} #before x+t>=omega
-	if((x+t)>omega) out<-0 else  #fractional ages
-	{ if((t%%1)==0) out<-object@lx[which(object@x==t+x)]/object@lx[which(object@x==x)] else {
-			z<-t%%1 #the fraction of year
-			#linearly interpolates if fractional age
-			pl<-object@lx[which(object@x==floor(t+x))]/object@lx[which(object@x==x)] # Kevin Owens: fix on this line, moving it out of the linear if statement so it can be used in other assumptions
-			if(fractional=="linear"){
-				ph<-object@lx[which(object@x==ceiling(t+x))]/object@lx[which(object@x==x)]
-				out<-z*ph+(1-z)*pl
-			} else if(fractional=="constant force") {
-				out<-pl*pxt(object=object, x=(x+floor(t)),t=1)^z # fix on this line
-			} else if(fractional=="hyperbolic") {
-				out<-pl*pxt(object=object, x=(x+floor(t)),t=1)/(1-(1-z)*qxt(object=object, x=(x+floor(t)),t=1)) # Kevin Owens: fix on this line
-			}
-		}			
-	}
-	return(out)
+  out <- NULL
+  #checks
+  if (!(class(object) %in% c("lifetable","actuarialtable","mdt")))
+    stop("Error! Only lifetable, actuarialtable or mdt classes are accepted")
+  if (class(object) == "mdt") {
+    #specific function for multiple decrements
+    out <-
+      ifelse(
+        missing(decrement),1 - .qxt.mdt(object = object,x = x,t = t),1 - .qxt.mdt(
+          object = object,x = x,t = t,decrement = decrement
+        )
+      )
+    return(out)
+  }
+  if (missing(x))
+    stop("Missing x")
+  if (any(x < 0,t < 0))
+    stop("Check x or t domain")
+  if (missing(t))
+    t = 1 #default 1
+  omega = getOmega(object)
+  #if the starting age is fractional apply probability laws
+  if ((x - floor(x)) > 0) {
+    integerAge = floor(x)
+    excess = x - floor(x)
+    out = pxt(
+      object = object, x = integerAge, t = excess + t, decrement = decrement
+    ) / pxt(
+      object = object, x = integerAge,t = excess, decrement = decrement
+    )
+    return(out)
+  }
+  #Rosa Corrales Patch
+ # if ((object@lx[omega] > 0) &&
+  #    (x + t) == (omega + 1)) {
+  #  out <- 1 / object@lx[which(object@x == x)]
+  #} else {
+    #before x+t>=omega
+    if ((x + t) > omega)
+      out <- 0
+    else
+      #fractional ages
+    {
+      if ((t %% 1) == 0)
+        out <-
+          object@lx[which(object@x == t + x)] / object@lx[which(object@x == x)]
+      else {
+        z <- t %% 1 #the fraction of year
+        #linearly interpolates if fractional age
+        pl <-
+          object@lx[which(object@x == floor(t + x))] / object@lx[which(object@x ==
+                                                                         x)] # Kevin Owens: fix on this line, moving it out of the linear if statement so it can be used in other assumptions
+        if (fractional == "linear") {
+          ph <-
+            object@lx[which(object@x == ceiling(t + x))] / object@lx[which(object@x ==
+                                                                             x)]
+          out <- z * ph + (1 - z) * pl
+        } else if (fractional == "constant force") {
+          out <- pl * pxt(object = object, x = (x + floor(t)),t = 1) ^ z # fix on this line
+        } else if (fractional == "hyperbolic") {
+          out <-
+            pl * pxt(object = object, x = (x + floor(t)),t = 1) / (1 - (1 - z) * qxt(
+              object = object, x = (x + floor(t)),t = 1
+            )) # Kevin Owens: fix on this line
+        }
+      }
+    }
+    
+#  }
+  return(out)
 }
 
 
@@ -315,6 +366,8 @@ exyzt<-function(tablesList,x,t=Inf, status="joint",type="Kx",...)
 
 #' @name mx2qx
 #' @title Mortality rates to Death probabilities
+#' 
+#' @description Function to convert mortality rates to probabilities of death
 #'
 #' @details Function to convert mortality rates to probabilities of death
 #' 
@@ -337,6 +390,8 @@ mx2qx <- function(mx, ax = 0.5)
 
 #' @name qx2mx
 #' @title Death Probabilities to Mortality Rates
+#' 
+#' @description Function to convert death probabilities to mortality rates
 #'
 #' @details Function to convert death probabilities to mortality rates
 #' 
